# Criteo API SDK for Python

## Introduction
API Client Libraries can facilitate your use of the Criteo API allowing you to build unique and customized solutions to serve your businesses and clients.
These libraries can reduce the amount of code you need to write in order to start accessing Criteo programmatically. They also can help expedite troubleshooting, should you encounter any issues.

More information on how to use Criteo API and these SDKs can be found at: [https://developers.criteo.com/](https://developers.criteo.com/).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- Package version: 2025.01.0.250425

## Requirements

Python 2.7 and 3.5+

## Installation & Usage
### pip install

```sh
pip install criteo-api-marketingsolutions-sdk==2025.01.0.250425
```
(you may need to run `pip` with root permission: `sudo pip install criteo-api-marketingsolutions-sdk==2025.01.0.250425`)

Then import the package:
```python
import criteo_api_marketingsolutions_v2025_01
```

### Manual Installation using [Setuptools](http://pypi.python.org/pypi/setuptools)

Download the code or clone the repository locally, then execute the following command:

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import criteo_api_marketingsolutions_v2025_01
```

## Example
There are multiple examples for the different OAuth flows that the SDK supports.
- See [test/example_application_with_client_credentials.py](test/example_application_with_client_credentials.py) for an example with Client Credentials.
- See [test/example_application_with_auth_code.py](test/example_application_with_auth_code.py) for an example with Authorization Code.
Once you follow the authorization code flow, you will have a refresh token that has to be used to regenerate access token for future usage. 
    - See [test/example_application_with_refresh_token.py](test/example_application_with_refresh_token.py) for an example with Refresh Token .

## Documentation for API Endpoints

The developers documentation is available at: *https://developers.criteo.com*.

All URIs are relative to *https://api.criteo.com*.

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdvertiserApi* | [**api_portfolio_get**](docs/AdvertiserApi.md#api_portfolio_get) | **GET** /2025-01/advertisers/me | 
*AnalyticsApi* | [**get_adset_report**](docs/AnalyticsApi.md#get_adset_report) | **POST** /2025-01/statistics/report | 
*AnalyticsApi* | [**get_placements_report**](docs/AnalyticsApi.md#get_placements_report) | **POST** /2025-01/placements/report | 
*AnalyticsApi* | [**get_transactions_report**](docs/AnalyticsApi.md#get_transactions_report) | **POST** /2025-01/transactions/report | 
*AnalyticsApi* | [**get_transparency_report**](docs/AnalyticsApi.md#get_transparency_report) | **POST** /2025-01/log-level/advertisers/{advertiser-id}/report | 
*AudienceApi* | [**bulk_create_audience_segments**](docs/AudienceApi.md#bulk_create_audience_segments) | **POST** /2025-01/marketing-solutions/audience-segments/create | 
*AudienceApi* | [**bulk_create_audiences**](docs/AudienceApi.md#bulk_create_audiences) | **POST** /2025-01/marketing-solutions/audiences/create | 
*AudienceApi* | [**bulk_delete_audience_segments**](docs/AudienceApi.md#bulk_delete_audience_segments) | **POST** /2025-01/marketing-solutions/audience-segments/delete | 
*AudienceApi* | [**bulk_delete_audiences**](docs/AudienceApi.md#bulk_delete_audiences) | **POST** /2025-01/marketing-solutions/audiences/delete | 
*AudienceApi* | [**bulk_update_audience_segments**](docs/AudienceApi.md#bulk_update_audience_segments) | **PATCH** /2025-01/marketing-solutions/audience-segments | 
*AudienceApi* | [**bulk_update_audiences**](docs/AudienceApi.md#bulk_update_audiences) | **PATCH** /2025-01/marketing-solutions/audiences | 
*AudienceApi* | [**call_01_audiences_audience_segment_id_contactlist_delete**](docs/AudienceApi.md#call_01_audiences_audience_segment_id_contactlist_delete) | **DELETE** /2025-01/audiences/{audience-segment-id}/contactlist | 
*AudienceApi* | [**call_01_audiences_audience_segment_id_contactlist_patch**](docs/AudienceApi.md#call_01_audiences_audience_segment_id_contactlist_patch) | **PATCH** /2025-01/audiences/{audience-segment-id}/contactlist | 
*AudienceApi* | [**call_01_marketing_solutions_audience_segments_audience_segment_id_contact_list_delete**](docs/AudienceApi.md#call_01_marketing_solutions_audience_segments_audience_segment_id_contact_list_delete) | **DELETE** /2025-01/marketing-solutions/audience-segments/{audience-segment-id}/contact-list | 
*AudienceApi* | [**call_01_marketing_solutions_audience_segments_audience_segment_id_contact_list_patch**](docs/AudienceApi.md#call_01_marketing_solutions_audience_segments_audience_segment_id_contact_list_patch) | **PATCH** /2025-01/marketing-solutions/audience-segments/{audience-segment-id}/contact-list | 
*AudienceApi* | [**compute_audience_segments_sizes**](docs/AudienceApi.md#compute_audience_segments_sizes) | **POST** /2025-01/marketing-solutions/audience-segments/compute-sizes | 
*AudienceApi* | [**compute_audiences_sizes**](docs/AudienceApi.md#compute_audiences_sizes) | **POST** /2025-01/marketing-solutions/audiences/compute-sizes | 
*AudienceApi* | [**estimate_audience_segment_size**](docs/AudienceApi.md#estimate_audience_segment_size) | **POST** /2025-01/marketing-solutions/audience-segments/estimate-size | 
*AudienceApi* | [**estimate_audience_size**](docs/AudienceApi.md#estimate_audience_size) | **POST** /2025-01/marketing-solutions/audiences/estimate-size | 
*AudienceApi* | [**get_audience_segment_contact_list_statistics**](docs/AudienceApi.md#get_audience_segment_contact_list_statistics) | **GET** /2025-01/marketing-solutions/audience-segments/{audience-segment-id}/contact-list/statistics | 
*AudienceApi* | [**get_audience_segments_in_market_brands**](docs/AudienceApi.md#get_audience_segments_in_market_brands) | **GET** /2025-01/marketing-solutions/audience-segments/in-market-brands | 
*AudienceApi* | [**get_audience_segments_in_market_interests**](docs/AudienceApi.md#get_audience_segments_in_market_interests) | **GET** /2025-01/marketing-solutions/audience-segments/in-market-interests | 
*AudienceApi* | [**search_audience_segments**](docs/AudienceApi.md#search_audience_segments) | **POST** /2025-01/marketing-solutions/audience-segments/search | 
*AudienceApi* | [**search_audiences**](docs/AudienceApi.md#search_audiences) | **POST** /2025-01/marketing-solutions/audiences/search | 
*CampaignApi* | [**create_ad_set_v24_q1**](docs/CampaignApi.md#create_ad_set_v24_q1) | **POST** /2025-01/marketing-solutions/ad-sets | 
*CampaignApi* | [**create_campaign**](docs/CampaignApi.md#create_campaign) | **POST** /2025-01/marketing-solutions/campaigns | 
*CampaignApi* | [**get_ad_set_v24_q1**](docs/CampaignApi.md#get_ad_set_v24_q1) | **GET** /2025-01/marketing-solutions/ad-sets/{ad-set-id} | 
*CampaignApi* | [**get_campaign_v23_q1**](docs/CampaignApi.md#get_campaign_v23_q1) | **GET** /2025-01/marketing-solutions/campaigns/{campaign-id} | 
*CampaignApi* | [**get_category_bid_list**](docs/CampaignApi.md#get_category_bid_list) | **GET** /2025-01/marketing-solutions/ad-sets/{ad-set-id}/category-bids | 
*CampaignApi* | [**get_display_multipliers**](docs/CampaignApi.md#get_display_multipliers) | **GET** /2025-01/marketing-solutions/ad-sets/{ad-set-id}/display-multipliers | 
*CampaignApi* | [**patch_ad_sets_v24_q1**](docs/CampaignApi.md#patch_ad_sets_v24_q1) | **PATCH** /2025-01/marketing-solutions/ad-sets | 
*CampaignApi* | [**patch_campaigns**](docs/CampaignApi.md#patch_campaigns) | **PATCH** /2025-01/marketing-solutions/campaigns | 
*CampaignApi* | [**patch_category_bid_list**](docs/CampaignApi.md#patch_category_bid_list) | **PATCH** /2025-01/marketing-solutions/ad-sets/{ad-set-id}/category-bids | 
*CampaignApi* | [**patch_display_multipliers**](docs/CampaignApi.md#patch_display_multipliers) | **PATCH** /2025-01/marketing-solutions/ad-sets/{ad-set-id}/display-multipliers | 
*CampaignApi* | [**search_ad_sets_v24_q1**](docs/CampaignApi.md#search_ad_sets_v24_q1) | **POST** /2025-01/marketing-solutions/ad-sets/search | 
*CampaignApi* | [**search_campaigns_v23_q1**](docs/CampaignApi.md#search_campaigns_v23_q1) | **POST** /2025-01/marketing-solutions/campaigns/search | 
*CampaignApi* | [**start_ad_sets**](docs/CampaignApi.md#start_ad_sets) | **POST** /2025-01/marketing-solutions/ad-sets/start | 
*CampaignApi* | [**stop_ad_sets**](docs/CampaignApi.md#stop_ad_sets) | **POST** /2025-01/marketing-solutions/ad-sets/stop | 
*CampaignApi* | [**update_ad_set_audience**](docs/CampaignApi.md#update_ad_set_audience) | **PUT** /2025-01/marketing-solutions/ad-sets/{ad-set-id}/audience | 
*CreativeApi* | [**create_advertiser_ad**](docs/CreativeApi.md#create_advertiser_ad) | **POST** /2025-01/marketing-solutions/advertisers/{advertiser-id}/ads | 
*CreativeApi* | [**create_advertiser_coupon**](docs/CreativeApi.md#create_advertiser_coupon) | **POST** /2025-01/marketing-solutions/advertisers/{advertiser-id}/coupons | 
*CreativeApi* | [**create_advertiser_creative**](docs/CreativeApi.md#create_advertiser_creative) | **POST** /2025-01/marketing-solutions/advertisers/{advertiser-id}/creatives | 
*CreativeApi* | [**delete_ad**](docs/CreativeApi.md#delete_ad) | **DELETE** /2025-01/marketing-solutions/ads/{id} | 
*CreativeApi* | [**delete_advertiser_coupon**](docs/CreativeApi.md#delete_advertiser_coupon) | **DELETE** /2025-01/marketing-solutions/advertisers/{advertiser-id}/coupons/{id} | 
*CreativeApi* | [**delete_creative**](docs/CreativeApi.md#delete_creative) | **DELETE** /2025-01/marketing-solutions/creatives/{id} | 
*CreativeApi* | [**edit_advertiser_coupon**](docs/CreativeApi.md#edit_advertiser_coupon) | **PUT** /2025-01/marketing-solutions/advertisers/{advertiser-id}/coupons/{id} | 
*CreativeApi* | [**edit_creative**](docs/CreativeApi.md#edit_creative) | **PUT** /2025-01/marketing-solutions/creatives/{id} | 
*CreativeApi* | [**generate_creative_preview**](docs/CreativeApi.md#generate_creative_preview) | **POST** /2025-01/marketing-solutions/creatives/{id}/preview | 
*CreativeApi* | [**get_ad**](docs/CreativeApi.md#get_ad) | **GET** /2025-01/marketing-solutions/ads/{id} | 
*CreativeApi* | [**get_advertiser_ads**](docs/CreativeApi.md#get_advertiser_ads) | **GET** /2025-01/marketing-solutions/advertisers/{advertiser-id}/ads | 
*CreativeApi* | [**get_advertiser_coupon**](docs/CreativeApi.md#get_advertiser_coupon) | **GET** /2025-01/marketing-solutions/advertisers/{advertiser-id}/coupons/{id} | 
*CreativeApi* | [**get_advertiser_coupon_preview**](docs/CreativeApi.md#get_advertiser_coupon_preview) | **GET** /2025-01/marketing-solutions/advertisers/{advertiser-id}/coupons/{id}/preview | 
*CreativeApi* | [**get_advertiser_coupon_supported_sizes**](docs/CreativeApi.md#get_advertiser_coupon_supported_sizes) | **GET** /2025-01/marketing-solutions/advertisers/{advertiser-id}/coupons-supported-sizes | 
*CreativeApi* | [**get_advertiser_coupons**](docs/CreativeApi.md#get_advertiser_coupons) | **GET** /2025-01/marketing-solutions/advertisers/{advertiser-id}/coupons | 
*CreativeApi* | [**get_advertiser_creatives**](docs/CreativeApi.md#get_advertiser_creatives) | **GET** /2025-01/marketing-solutions/advertisers/{advertiser-id}/creatives | 
*CreativeApi* | [**get_creative**](docs/CreativeApi.md#get_creative) | **GET** /2025-01/marketing-solutions/creatives/{id} | 
*GatewayApi* | [**get_current_application**](docs/GatewayApi.md#get_current_application) | **GET** /2025-01/marketing-solutions/me | 


## Documentation For Models

 - [Ad](docs/Ad.md)
 - [AdSetAudienceLinkEntityV1](docs/AdSetAudienceLinkEntityV1.md)
 - [AdSetAudienceLinkEntityV1Resource](docs/AdSetAudienceLinkEntityV1Resource.md)
 - [AdSetAudienceLinkEntityV1Response](docs/AdSetAudienceLinkEntityV1Response.md)
 - [AdSetAudienceLinkInputEntityV1](docs/AdSetAudienceLinkInputEntityV1.md)
 - [AdSetCategoryBid](docs/AdSetCategoryBid.md)
 - [AdSetCategoryBidListResponse](docs/AdSetCategoryBidListResponse.md)
 - [AdSetCategoryBidResource](docs/AdSetCategoryBidResource.md)
 - [AdSetDeliveryLimitationsV24Q1](docs/AdSetDeliveryLimitationsV24Q1.md)
 - [AdSetDisplayMultiplier](docs/AdSetDisplayMultiplier.md)
 - [AdSetDisplayMultiplierListResponse](docs/AdSetDisplayMultiplierListResponse.md)
 - [AdSetDisplayMultiplierResource](docs/AdSetDisplayMultiplierResource.md)
 - [AdSetFrequencyCappingV24Q1](docs/AdSetFrequencyCappingV24Q1.md)
 - [AdSetGeoLocationV24Q1](docs/AdSetGeoLocationV24Q1.md)
 - [AdSetSearchFilterV24Q1](docs/AdSetSearchFilterV24Q1.md)
 - [AdSetSearchRequestV24Q1](docs/AdSetSearchRequestV24Q1.md)
 - [AdSetTargetingRuleV24Q1](docs/AdSetTargetingRuleV24Q1.md)
 - [AdSetTargetingV24Q1](docs/AdSetTargetingV24Q1.md)
 - [AdWrite](docs/AdWrite.md)
 - [AdaptiveAttributes](docs/AdaptiveAttributes.md)
 - [AdaptiveColors](docs/AdaptiveColors.md)
 - [AdaptiveWriteAttributes](docs/AdaptiveWriteAttributes.md)
 - [AlgebraNodeV1](docs/AlgebraNodeV1.md)
 - [ApplicationSummaryModel](docs/ApplicationSummaryModel.md)
 - [ApplicationSummaryModelResource](docs/ApplicationSummaryModelResource.md)
 - [ApplicationSummaryModelResponse](docs/ApplicationSummaryModelResponse.md)
 - [AudienceBulkCreateInputV1](docs/AudienceBulkCreateInputV1.md)
 - [AudienceBulkDeleteInputV1](docs/AudienceBulkDeleteInputV1.md)
 - [AudienceBulkUpdateInputV1](docs/AudienceBulkUpdateInputV1.md)
 - [AudienceComputeSizeEntityV1Resource](docs/AudienceComputeSizeEntityV1Resource.md)
 - [AudienceComputeSizesInputV1](docs/AudienceComputeSizesInputV1.md)
 - [AudienceCreateEntityV1](docs/AudienceCreateEntityV1.md)
 - [AudienceCreateEntityV1Resource](docs/AudienceCreateEntityV1Resource.md)
 - [AudienceDeleteEntityV1Resource](docs/AudienceDeleteEntityV1Resource.md)
 - [AudienceEntityV1](docs/AudienceEntityV1.md)
 - [AudienceEntityV1AudienceSearchMetadataV1ListResponse](docs/AudienceEntityV1AudienceSearchMetadataV1ListResponse.md)
 - [AudienceEntityV1ListResponse](docs/AudienceEntityV1ListResponse.md)
 - [AudienceEntityV1Resource](docs/AudienceEntityV1Resource.md)
 - [AudienceError](docs/AudienceError.md)
 - [AudienceEstimateSizeEntityV1](docs/AudienceEstimateSizeEntityV1.md)
 - [AudienceEstimateSizeEntityV1Resource](docs/AudienceEstimateSizeEntityV1Resource.md)
 - [AudienceEstimateSizeInputV1](docs/AudienceEstimateSizeInputV1.md)
 - [AudienceIdEntityV1ListResponse](docs/AudienceIdEntityV1ListResponse.md)
 - [AudienceIdEntityV1Resource](docs/AudienceIdEntityV1Resource.md)
 - [AudienceNameDescription](docs/AudienceNameDescription.md)
 - [AudienceSearchEntityV1](docs/AudienceSearchEntityV1.md)
 - [AudienceSearchEntityV1Resource](docs/AudienceSearchEntityV1Resource.md)
 - [AudienceSearchInputV1](docs/AudienceSearchInputV1.md)
 - [AudienceSearchMetadataV1](docs/AudienceSearchMetadataV1.md)
 - [AudienceSegmentBulkCreateInputV1](docs/AudienceSegmentBulkCreateInputV1.md)
 - [AudienceSegmentBulkDeleteInputV1](docs/AudienceSegmentBulkDeleteInputV1.md)
 - [AudienceSegmentBulkUpdateInputV1](docs/AudienceSegmentBulkUpdateInputV1.md)
 - [AudienceSegmentComputeSizeEntityV1Resource](docs/AudienceSegmentComputeSizeEntityV1Resource.md)
 - [AudienceSegmentComputeSizesInputV1](docs/AudienceSegmentComputeSizesInputV1.md)
 - [AudienceSegmentCreateEntityV1](docs/AudienceSegmentCreateEntityV1.md)
 - [AudienceSegmentCreateEntityV1Resource](docs/AudienceSegmentCreateEntityV1Resource.md)
 - [AudienceSegmentDeleteEntityV1Resource](docs/AudienceSegmentDeleteEntityV1Resource.md)
 - [AudienceSegmentEntityV1](docs/AudienceSegmentEntityV1.md)
 - [AudienceSegmentEntityV1AudienceSegmentSearchMetadataV1ListResponse](docs/AudienceSegmentEntityV1AudienceSegmentSearchMetadataV1ListResponse.md)
 - [AudienceSegmentEntityV1ListResponse](docs/AudienceSegmentEntityV1ListResponse.md)
 - [AudienceSegmentEntityV1Resource](docs/AudienceSegmentEntityV1Resource.md)
 - [AudienceSegmentEstimateSizeInputV1](docs/AudienceSegmentEstimateSizeInputV1.md)
 - [AudienceSegmentIdEntityV1ListResponse](docs/AudienceSegmentIdEntityV1ListResponse.md)
 - [AudienceSegmentIdEntityV1Resource](docs/AudienceSegmentIdEntityV1Resource.md)
 - [AudienceSegmentSearchEntityV1](docs/AudienceSegmentSearchEntityV1.md)
 - [AudienceSegmentSearchEntityV1Resource](docs/AudienceSegmentSearchEntityV1Resource.md)
 - [AudienceSegmentSearchInputV1](docs/AudienceSegmentSearchInputV1.md)
 - [AudienceSegmentSearchMetadataV1](docs/AudienceSegmentSearchMetadataV1.md)
 - [AudienceSegmentSizeEntityV1](docs/AudienceSegmentSizeEntityV1.md)
 - [AudienceSegmentSizeEntityV1ListResponse](docs/AudienceSegmentSizeEntityV1ListResponse.md)
 - [AudienceSegmentSizeEntityV1Resource](docs/AudienceSegmentSizeEntityV1Resource.md)
 - [AudienceSegmentSizeEstimationEntityV1](docs/AudienceSegmentSizeEstimationEntityV1.md)
 - [AudienceSegmentSizeEstimationEntityV1Resource](docs/AudienceSegmentSizeEstimationEntityV1Resource.md)
 - [AudienceSegmentSizeEstimationV1](docs/AudienceSegmentSizeEstimationV1.md)
 - [AudienceSegmentSizeEstimationV1Resource](docs/AudienceSegmentSizeEstimationV1Resource.md)
 - [AudienceSegmentSizeEstimationV1Response](docs/AudienceSegmentSizeEstimationV1Response.md)
 - [AudienceSegmentUpdateEntityV1](docs/AudienceSegmentUpdateEntityV1.md)
 - [AudienceSegmentUpdateEntityV1Resource](docs/AudienceSegmentUpdateEntityV1Resource.md)
 - [AudienceSizeEntityV1](docs/AudienceSizeEntityV1.md)
 - [AudienceSizeEntityV1ListResponse](docs/AudienceSizeEntityV1ListResponse.md)
 - [AudienceSizeEntityV1Resource](docs/AudienceSizeEntityV1Resource.md)
 - [AudienceSizeEstimationV1](docs/AudienceSizeEstimationV1.md)
 - [AudienceSizeEstimationV1Resource](docs/AudienceSizeEstimationV1Resource.md)
 - [AudienceSizeEstimationV1Response](docs/AudienceSizeEstimationV1Response.md)
 - [AudienceUpdateEntityV1](docs/AudienceUpdateEntityV1.md)
 - [AudienceUpdateEntityV1Resource](docs/AudienceUpdateEntityV1Resource.md)
 - [AudienceWarning](docs/AudienceWarning.md)
 - [AutomatedBudgetConfigurationV23Q1](docs/AutomatedBudgetConfigurationV23Q1.md)
 - [BasicAudienceDefinition](docs/BasicAudienceDefinition.md)
 - [BehavioralV1](docs/BehavioralV1.md)
 - [BudgetAutomation](docs/BudgetAutomation.md)
 - [BudgetAutomationConfiguration](docs/BudgetAutomationConfiguration.md)
 - [CampaignBudgetAutomationV23Q1](docs/CampaignBudgetAutomationV23Q1.md)
 - [CampaignSearchFiltersV23Q1](docs/CampaignSearchFiltersV23Q1.md)
 - [CampaignSearchRequestV23Q1](docs/CampaignSearchRequestV23Q1.md)
 - [CampaignSpendLimitV23Q1](docs/CampaignSpendLimitV23Q1.md)
 - [CampaignV23Q1](docs/CampaignV23Q1.md)
 - [CampaignV23Q1ListResponse](docs/CampaignV23Q1ListResponse.md)
 - [CampaignV23Q1Resource](docs/CampaignV23Q1Resource.md)
 - [CampaignV23Q1Response](docs/CampaignV23Q1Response.md)
 - [CommonProblem](docs/CommonProblem.md)
 - [ContactListStatisticsEntityV1](docs/ContactListStatisticsEntityV1.md)
 - [ContactListStatisticsEntityV1Resource](docs/ContactListStatisticsEntityV1Resource.md)
 - [ContactListStatisticsEntityV1Response](docs/ContactListStatisticsEntityV1Response.md)
 - [ContactListV1](docs/ContactListV1.md)
 - [ContactlistAmendment](docs/ContactlistAmendment.md)
 - [ContactlistAmendmentAttributes](docs/ContactlistAmendmentAttributes.md)
 - [ContactlistAmendmentRequest](docs/ContactlistAmendmentRequest.md)
 - [ContactlistOperation](docs/ContactlistOperation.md)
 - [ContactlistOperationAttributes](docs/ContactlistOperationAttributes.md)
 - [Coupon](docs/Coupon.md)
 - [CouponSupportedSizes](docs/CouponSupportedSizes.md)
 - [CreateAdSetBiddingV24Q1](docs/CreateAdSetBiddingV24Q1.md)
 - [CreateAdSetBudgetV24Q1](docs/CreateAdSetBudgetV24Q1.md)
 - [CreateAdSetGeoLocationV24Q1](docs/CreateAdSetGeoLocationV24Q1.md)
 - [CreateAdSetScheduleV24Q1](docs/CreateAdSetScheduleV24Q1.md)
 - [CreateAdSetTargetingV24Q1](docs/CreateAdSetTargetingV24Q1.md)
 - [CreateAdSetV24Q1](docs/CreateAdSetV24Q1.md)
 - [CreateAdSetV24Q1Request](docs/CreateAdSetV24Q1Request.md)
 - [CreateAdSetV24Q1Resource](docs/CreateAdSetV24Q1Resource.md)
 - [CreateCampaign](docs/CreateCampaign.md)
 - [CreateCampaignRequest](docs/CreateCampaignRequest.md)
 - [CreateCampaignResource](docs/CreateCampaignResource.md)
 - [CreateCampaignSpendLimit](docs/CreateCampaignSpendLimit.md)
 - [CreateCoupon](docs/CreateCoupon.md)
 - [CreateImageSlide](docs/CreateImageSlide.md)
 - [Creative](docs/Creative.md)
 - [CreativeWrite](docs/CreativeWrite.md)
 - [CriteoApiError](docs/CriteoApiError.md)
 - [CriteoApiWarning](docs/CriteoApiWarning.md)
 - [DeleteAudienceContactListResponse](docs/DeleteAudienceContactListResponse.md)
 - [DynamicAttributes](docs/DynamicAttributes.md)
 - [DynamicWriteAttributes](docs/DynamicWriteAttributes.md)
 - [EntityOfPortfolioMessage](docs/EntityOfPortfolioMessage.md)
 - [ErrorCodeResponse](docs/ErrorCodeResponse.md)
 - [GetPortfolioResponse](docs/GetPortfolioResponse.md)
 - [HtmlTagAttributes](docs/HtmlTagAttributes.md)
 - [HtmlTagWriteAttributes](docs/HtmlTagWriteAttributes.md)
 - [ImageAttributes](docs/ImageAttributes.md)
 - [ImageSet](docs/ImageSet.md)
 - [ImageSetBase64](docs/ImageSetBase64.md)
 - [ImageShape](docs/ImageShape.md)
 - [ImageSlide](docs/ImageSlide.md)
 - [ImageWriteAttributes](docs/ImageWriteAttributes.md)
 - [InMarketAudienceSegmentBrandEntityV1](docs/InMarketAudienceSegmentBrandEntityV1.md)
 - [InMarketAudienceSegmentBrandEntityV1ListResponse](docs/InMarketAudienceSegmentBrandEntityV1ListResponse.md)
 - [InMarketAudienceSegmentBrandEntityV1Resource](docs/InMarketAudienceSegmentBrandEntityV1Resource.md)
 - [InMarketAudienceSegmentInterestEntityV1](docs/InMarketAudienceSegmentInterestEntityV1.md)
 - [InMarketAudienceSegmentInterestEntityV1ListResponse](docs/InMarketAudienceSegmentInterestEntityV1ListResponse.md)
 - [InMarketAudienceSegmentInterestEntityV1Resource](docs/InMarketAudienceSegmentInterestEntityV1Resource.md)
 - [InMarketCreateV1](docs/InMarketCreateV1.md)
 - [InMarketSizeEstimationV1](docs/InMarketSizeEstimationV1.md)
 - [InMarketUpdateV1](docs/InMarketUpdateV1.md)
 - [InMarketV1](docs/InMarketV1.md)
 - [LocationCreateV1](docs/LocationCreateV1.md)
 - [LocationSizeEstimationV1](docs/LocationSizeEstimationV1.md)
 - [LocationUpdateV1](docs/LocationUpdateV1.md)
 - [LocationV1](docs/LocationV1.md)
 - [LookalikeCreateV1](docs/LookalikeCreateV1.md)
 - [LookalikeUpdateV1](docs/LookalikeUpdateV1.md)
 - [LookalikeV1](docs/LookalikeV1.md)
 - [ModifyAudienceResponse](docs/ModifyAudienceResponse.md)
 - [NillableAdSetTargetingRuleV24Q1](docs/NillableAdSetTargetingRuleV24Q1.md)
 - [NillableAdSetTargetingRuleV24Q1Value](docs/NillableAdSetTargetingRuleV24Q1Value.md)
 - [NillableDateTime](docs/NillableDateTime.md)
 - [NillableDecimal](docs/NillableDecimal.md)
 - [NillableGenderV1](docs/NillableGenderV1.md)
 - [NillableInt32](docs/NillableInt32.md)
 - [NillableString](docs/NillableString.md)
 - [Outcome](docs/Outcome.md)
 - [PatchAdSetBiddingV24Q1](docs/PatchAdSetBiddingV24Q1.md)
 - [PatchAdSetBudgetV24Q1](docs/PatchAdSetBudgetV24Q1.md)
 - [PatchAdSetCategoryBid](docs/PatchAdSetCategoryBid.md)
 - [PatchAdSetCategoryBidListRequest](docs/PatchAdSetCategoryBidListRequest.md)
 - [PatchAdSetCategoryBidResource](docs/PatchAdSetCategoryBidResource.md)
 - [PatchAdSetCategoryBidResultListResponse](docs/PatchAdSetCategoryBidResultListResponse.md)
 - [PatchAdSetCategoryBidResultResource](docs/PatchAdSetCategoryBidResultResource.md)
 - [PatchAdSetDisplayMultiplier](docs/PatchAdSetDisplayMultiplier.md)
 - [PatchAdSetDisplayMultiplierListRequest](docs/PatchAdSetDisplayMultiplierListRequest.md)
 - [PatchAdSetDisplayMultiplierResource](docs/PatchAdSetDisplayMultiplierResource.md)
 - [PatchAdSetDisplayMultiplierResultListResponse](docs/PatchAdSetDisplayMultiplierResultListResponse.md)
 - [PatchAdSetDisplayMultiplierResultResource](docs/PatchAdSetDisplayMultiplierResultResource.md)
 - [PatchAdSetSchedulingV24Q1](docs/PatchAdSetSchedulingV24Q1.md)
 - [PatchAdSetV24Q1](docs/PatchAdSetV24Q1.md)
 - [PatchCampaign](docs/PatchCampaign.md)
 - [PatchCampaignListRequest](docs/PatchCampaignListRequest.md)
 - [PatchCampaignSpendLimit](docs/PatchCampaignSpendLimit.md)
 - [PatchCampaignWriteResource](docs/PatchCampaignWriteResource.md)
 - [PatchMarketingCampaignBudgetAutomation](docs/PatchMarketingCampaignBudgetAutomation.md)
 - [PatchResultCampaignListResponse](docs/PatchResultCampaignListResponse.md)
 - [PatchResultCampaignReadResource](docs/PatchResultCampaignReadResource.md)
 - [PlacementsReportQueryMessage](docs/PlacementsReportQueryMessage.md)
 - [PlacementsReportQueryMessageListRequest](docs/PlacementsReportQueryMessageListRequest.md)
 - [PlacementsReportQueryMessageResource](docs/PlacementsReportQueryMessageResource.md)
 - [PointOfInterestV1](docs/PointOfInterestV1.md)
 - [PortfolioMessage](docs/PortfolioMessage.md)
 - [ProspectingCreateV1](docs/ProspectingCreateV1.md)
 - [ProspectingUpdateV1](docs/ProspectingUpdateV1.md)
 - [ProspectingV1](docs/ProspectingV1.md)
 - [ReadAdSetBiddingV24Q1](docs/ReadAdSetBiddingV24Q1.md)
 - [ReadAdSetBudgetV24Q1](docs/ReadAdSetBudgetV24Q1.md)
 - [ReadAdSetScheduleV24Q1](docs/ReadAdSetScheduleV24Q1.md)
 - [ReadAdSetV24Q1](docs/ReadAdSetV24Q1.md)
 - [ReadModelAdSetId](docs/ReadModelAdSetId.md)
 - [ReadModelAdSetIdV24Q1](docs/ReadModelAdSetIdV24Q1.md)
 - [ReadModelReadAdSetV24Q1](docs/ReadModelReadAdSetV24Q1.md)
 - [RequestsAdSetId](docs/RequestsAdSetId.md)
 - [RequestsPatchAdSetV24Q1](docs/RequestsPatchAdSetV24Q1.md)
 - [ResourceCollectionOutcomeOfAd](docs/ResourceCollectionOutcomeOfAd.md)
 - [ResourceCollectionOutcomeOfCoupon](docs/ResourceCollectionOutcomeOfCoupon.md)
 - [ResourceCollectionOutcomeOfCreative](docs/ResourceCollectionOutcomeOfCreative.md)
 - [ResourceInputOfAdWrite](docs/ResourceInputOfAdWrite.md)
 - [ResourceInputOfCreateCoupon](docs/ResourceInputOfCreateCoupon.md)
 - [ResourceInputOfCreativeWrite](docs/ResourceInputOfCreativeWrite.md)
 - [ResourceInputOfUpdateCoupon](docs/ResourceInputOfUpdateCoupon.md)
 - [ResourceOfAd](docs/ResourceOfAd.md)
 - [ResourceOfAdWrite](docs/ResourceOfAdWrite.md)
 - [ResourceOfCoupon](docs/ResourceOfCoupon.md)
 - [ResourceOfCouponSupportedSizes](docs/ResourceOfCouponSupportedSizes.md)
 - [ResourceOfCreateCoupon](docs/ResourceOfCreateCoupon.md)
 - [ResourceOfCreative](docs/ResourceOfCreative.md)
 - [ResourceOfCreativeWrite](docs/ResourceOfCreativeWrite.md)
 - [ResourceOfUpdateCoupon](docs/ResourceOfUpdateCoupon.md)
 - [ResourceOutcomeOfAd](docs/ResourceOutcomeOfAd.md)
 - [ResourceOutcomeOfCoupon](docs/ResourceOutcomeOfCoupon.md)
 - [ResourceOutcomeOfCouponSupportedSizes](docs/ResourceOutcomeOfCouponSupportedSizes.md)
 - [ResourceOutcomeOfCreative](docs/ResourceOutcomeOfCreative.md)
 - [ResponseReadAdSetV24Q1](docs/ResponseReadAdSetV24Q1.md)
 - [ResponsesAdSetId](docs/ResponsesAdSetId.md)
 - [ResponsesAdSetIdV24Q1](docs/ResponsesAdSetIdV24Q1.md)
 - [ResponsesReadAdSetV24Q1](docs/ResponsesReadAdSetV24Q1.md)
 - [RetargetingCreateV1](docs/RetargetingCreateV1.md)
 - [RetargetingUpdateV1](docs/RetargetingUpdateV1.md)
 - [RetargetingV1](docs/RetargetingV1.md)
 - [Size](docs/Size.md)
 - [StatisticsReportQueryMessage](docs/StatisticsReportQueryMessage.md)
 - [Tag](docs/Tag.md)
 - [TransactionsReportQueryMessage](docs/TransactionsReportQueryMessage.md)
 - [TransactionsReportQueryMessageListRequest](docs/TransactionsReportQueryMessageListRequest.md)
 - [TransactionsReportQueryMessageResource](docs/TransactionsReportQueryMessageResource.md)
 - [TransparencyQueryMessage](docs/TransparencyQueryMessage.md)
 - [TransparencyReport](docs/TransparencyReport.md)
 - [TransparencyReportFile](docs/TransparencyReportFile.md)
 - [TransparencyReportListResponse](docs/TransparencyReportListResponse.md)
 - [TransparencyReportResource](docs/TransparencyReportResource.md)
 - [UpdateCoupon](docs/UpdateCoupon.md)
 - [VideoDetail](docs/VideoDetail.md)
 - [WriteModelAdSetId](docs/WriteModelAdSetId.md)
 - [WriteModelPatchAdSetV24Q1](docs/WriteModelPatchAdSetV24Q1.md)


## Disclaimer

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.